# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2018/7/16 0016
__author__ = 'huohuo'
from PIL import Image

img = Image.open(r'D:\pythonproject\report\data\4.5.1signature.png')
sp = img.size
w, h = sp[0], sp[1]
region = (0, h/3, w, h/3 * 2)

#裁切图片
cropImg = img.crop(region)

#保存裁切后的图片
cropImg.save(r'D:\pythonproject\report\data\4.5.1signature1.png')

if __name__ == "__main__":
    pass
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2019/2/13 0013
__author__ = 'huohuo'

import json
import time
import requests
from jy_word.web_tool import format_time
from Crypto.PublicKey import RSA
from Crypto.Signature import PKCS1_v1_5
from Crypto.Hash import SHA256
from base64 import decodestring, encodestring
from urllib import quote_plus

ALIPAY_APPID = '2016092300580658'
ALIPAY_APPID = '2019012963189101'
ALIPAY_URL = 'https://openapi.alipay.com/gateway.do'
app_private_key = ''''''
sign = 'fwx6t6UZl2Th5Q1c+rkdatplNkJ68LnIf1Ipv9MgAQHRutLTLoz/mYBQOotBYy5fAC94A1RPGvV2QJHD15VKVhDcOnIm0xjF7HiR7evlDzH/Rg9xUSSYhTq/u9lnibWn2gdXqwmhsiJ6F9j4FNmRE9LseOowLqAlJTHzKRVjC7Tp31hetEO3uKpl0YCBXHYyzcU0Ac8oaoKbkjFnvSxPKdsWcsxj7gYMszxOiUZDzgInxns9ke5MnWRFLC1v3Hs96/+POCT2vMbOtdhPTCYUz6Hvsy73IZp5FbcluzxCiEiYT8UnYXKSrqQMnobhXBAOZ0MMw/gENGL/XqwKygHzvw=='


def init_sign(timestamp):
    method = 'alipay.user.info.auth'
    method = 'alipay.mobile.public.menu.add'
    params = 'app_id=%s&biz_content={"button":[{"actionParam":"ZFB_HFCZ","actionType":"out","name":"话费充值"},{"name":"查询","subButton":[{"actionParam":"ZFB_YECX","actionType":"out","name":"余额查询"},{"actionParam":"ZFB_LLCX","actionType":"out","name":"流量查询"},{"actionParam":"ZFB_HFCX","actionType":"out","name":"话费查询"}]},{"actionParam":"http://m.alipay.com","actionType":"link","name":"最新优惠"}]}&charset=GBK&method=%s&sign_type=RSA2&timestamp=%s&version=1.0'% (ALIPAY_APPID, method, timestamp)
    biz_content = {"button":[{"actionParam":"ZFB_HFCZ","actionType":"out","name":"话费充值"},{"name":"查询","subButton":[{"actionParam":"ZFB_YECX","actionType":"out","name":"余额查询"},{"actionParam":"ZFB_LLCX","actionType":"out","name":"流量查询"},{"actionParam":"ZFB_HFCX","actionType":"out","name":"话费查询"}]},{"actionParam":"http://m.alipay.com","actionType":"link","name":"最新优惠"}]}

    url1 = '%s?app_id=%s&biz_content=%s&charset=GBK&method=alipay.mobile.public.menu.add&sign_type=RSA2&timestamp=%s&version=1.0' % (ALIPAY_URL, ALIPAY_APPID, biz_content, timestamp)
    url1 = '%s?%s' % (ALIPAY_URL, params)
    print url1

    response = requests.request('post', url1)
    print response.status_code
    if response.status_code == 200:
        print response.text
    else:
        print response.text


def init_sign1(timestamp):
    method = 'alipay.mobile.public.menu.add'
    charset = 'utf-8'
    params = 'app_id=%s&biz_content={"button":[{"actionParam":"ZFB_HFCZ","actionType":"out","name":"话费充值"},{"name":"查询","subButton":[{"actionParam":"ZFB_YECX","actionType":"out","name":"余额查询"},{"actionParam":"ZFB_LLCX","actionType":"out","name":"流量查询"},{"actionParam":"ZFB_HFCX","actionType":"out","name":"话费查询"}]},{"actionParam":"http://m.alipay.com","actionType":"link","name":"最新优惠"}]}&charset=%s&method=%s&timestamp=%s&version=1.0'% (ALIPAY_APPID, charset, method, timestamp)
    url1 = '%s?%s' % (ALIPAY_URL, params)
    print url1
    response = requests.request('post', url1)
    print response.status_code
    if response.status_code == 200:
        print response.json()
    else:
        print response.text


if __name__ == '__main__':
    out_trade_no = int(time.time())
    timestamp = format_time(out_trade_no)
    total_amount = 0.01
    init_sign1(timestamp)



# -*- coding: utf-8 -*-
import sys
import uuid
import hashlib
import time
import requests
from jy_word.File import File

reload(sys)
sys.setdefaultencoding('utf-8')

YOUDAO_URL = 'https://openapi.youdao.com/api'
APP_KEY = '77aa07b662b2a223'
APP_SECRET = '1ITqWf7O92mdBe4QzZHUHoLR98XeLPmO'


my_file = File()
tumor_evidence_data = my_file.read('tumor_evidence.json')
tumor_evidences = tumor_evidence_data.get('data')


def encrypt(signStr):
    hash_algorithm = hashlib.sha256()
    hash_algorithm.update(signStr.encode('utf-8'))
    return hash_algorithm.hexdigest()


def truncate(q):
    if q is None:
        return None
    q_utf8 = q.decode("utf-8")
    size = len(q_utf8)
    return q_utf8 if size <= 20 else q_utf8[0:10] + str(size) + q_utf8[size - 10:size]


def do_request(data):
    headers = {'Content-Type': 'application/x-www-form-urlencoded'}
    return requests.post(YOUDAO_URL, data=data, headers=headers)


def connect(q):
    data = {}
    data['from'] = '源语言'
    data['to'] = '目标语言'
    data['signType'] = 'v3'
    curtime = str(int(time.time()))
    data['curtime'] = curtime
    salt = str(uuid.uuid1())
    signStr = APP_KEY + truncate(q) + salt + curtime + APP_SECRET
    sign = encrypt(signStr)
    data['appKey'] = APP_KEY
    data['q'] = q
    data['salt'] = salt
    data['sign'] = sign

    response = do_request(data)
    contentType = response.headers['Content-Type']
    if contentType == "audio/mp3":
        millis = int(round(time.time() * 1000))
        filePath = "合成的音频存储路径" + str(millis) + ".mp3"
        fo = open(filePath, 'wb')
        fo.write(response.content)
        fo.close()
    else:
        res = response.json()
        if res is not None:
            translation = res.get('translation')
            if isinstance(translation, list):
                if len(translation) > 0:
                    return translation[0]
    return None


import os
dir_name = 'evidences'
if os.path.exists(dir_name) is False:
    os.makedirs(dir_name)


def get_item(item):
    no = item.get('no')
    evidence_statement = item.get('evidence_statement')
    evidence_statement_cn = ''
    if evidence_statement:
        evidence_statement = evidence_statement.strip()
        if evidence_statement:
            evidence_statement_cn = connect(evidence_statement)
    print no, evidence_statement_cn
    item['evidence_statement_cn'] = evidence_statement_cn or ''
    file_path = os.path.join(dir_name, '%s.json' % no)
    my_file.write(file_path, item)
    return item


def get_items():
    items = []
    for item in tumor_evidences:
        item = get_item(item)
        items.append(item)
    my_file.write('tumor_evidences_cn.json', items)


def evidence2excel():
    items = my_file.read('tumor_evidences_cn.json')
    import xlwt
    wb = xlwt.Workbook(encoding='utf-8')
    sheet = wb.add_sheet('Sheet1')
    for index, item in enumerate(items):
        for col, k in enumerate(item.keys()):
            v = item.get(k)
            if index == 0:
                sheet.write(index, col, label=k)
            sheet.write(index+1, col, label=v)
    wb.save('tumor_evidences_cn.xls')


if __name__ == '__main__':
    # get_items()
    evidence2excel()


#! /usr/bin/env python
# coding: utf-8
__author__ = 'huo'
import sys
import os
reload(sys)
sys.setdefaultencoding('utf-8')

from jy_word.File import File
from jy_word.Word import Paragraph, Set_page, Table, Tc, Tr, HyperLink, write_pkg_parts, get_imgs, get_img
img_info_path = 'img_info.json'


class Run:
    def __init__(self, img_info_path='', family='', family_en='Times New Roman', familyTheme = 'minorEastAsia', color='auto'):
        self.test = 'hello word'
        self.familyTheme = familyTheme
        self.family_en = family_en
        self.family = family
        self.img_info_path = img_info_path
        self.color = color

    def text(self, content, size=10.5, weight=0, underline='', space=False, wingdings=False, windChar='F09E',
             vertAlign='', lastRender=False, br='', color='', italic=False, fill='', rStyle=False, rStyleVal='',
             szCs=0, lang='', noProof=False, shade='',
             strike=False
             ):
        # https://www.jb51.net/web/560864.html
        content = str(content).replace("<", "＜").replace(">", "＞").replace('&', '＆')
        rFonts = '<w:rFonts w:ascii="%s" ' % (self.family if self.family_en == '' else self.family_en)
        if self.family == '':
            rFonts += 'w:eastAsiaTheme="%s" ' % self.familyTheme
        else:
            rFonts += 'w:eastAsia="%s" ' % self.family
        if self.family_en != '':
            rFonts += 'w:hAnsi="%s" w:cs="%s"' % (self.family_en, self.family_en)
        rFonts += '/>'
        sz = '<w:sz w:val="%d"/>' % int(size * 2)
        if szCs != 0:
            sz += '<w:szCs w:val="%d"/>' % int(szCs)
        uuu = ''
        weight_str = ""
        lastRendered = ''
        if weight != 0:
            weight_str = "<w:b/><w:bCs/>"
        if underline != '':
            uuu = '<w:u w:val="%s"/>' % underline
        color = '<w:color w:val="%s"/>' % (self.color if color == '' else color)
        if vertAlign == 'top':
            vertAlign = '<w:vertAlign w:val="superscript"/>'
        elif vertAlign == 'bottom':
            vertAlign = '<w:vertAlign w:val="subscript"/>'
        if italic:
            italic = '<w:i/>'
        else:
            italic = ''
        if rStyle:
            sz += '<w:rStyle w:val="%s"/>' % rStyleVal
        rPr = '<w:rPr>' + rFonts + weight_str + italic + uuu + sz + vertAlign + color
        if noProof:
            rPr += '<w:noProof/>'
        if lang != '':
            rPr += '<w:lang w:val="zh-CN"/>'
        if shade != '':
            rPr += '<w:highlight w:val="%s"/>' % shade
        if strike:
            rPr += '<w:strike/>'
        rPr += '</w:rPr>'
        wt = ''
        if content != '':
            space1 = ''
            if space:
                space1 = ' xml:space="preserve"'
            wt = '<w:t%s>%s</w:t>' % (space1, content)
        if lastRender:
            lastRendered = '<w:lastRenderedPageBreak/>'
        wingdings1 = ''
        if wingdings:
            wingdings1 = '<w:sym w:font="Wingdings" w:char="%s"/>' % windChar
        shd = ''
        if fill != '':
            shd = '<w:shd w:val="clear" w:color="auto" w:fill="%s"/>' % fill
        r = '<w:r w:rsidRPr="008059BD">%s%s%s%s%s</w:r>' % (rPr, wingdings1, lastRendered, shd, wt)
        if br == 'column':
            r += '<w:r w:rsidR="003334DE"><w:br w:type="column"/></w:r>'
        return r

    def br(self, br_type='column'):
        r = '<w:r w:rsidR="003334DE"><w:br w:type="%s"/></w:r>' % br_type
        return r

    def picture(self, cx=0, cy=0, rId='', relativeFrom=['column', 'paragraph'], posOffset=[0, 0], align=['', ''],
                wrap='tight', text_wrapping='anchor', zoom=1, img_info=None):
        if rId.startswith('rId'):
            rId = rId[3:]
        if self.img_info_path:
            if img_info is None:
                img_info = get_img(self.img_info_path, rId)
            if img_info is None:
                return ''
        if img_info is not None:
            cx1 = img_info['w']
            cy1 = img_info['h']
            if cx == 0 and cy == 0:
                zoom = zoom
            elif cx == 0 or cx * cy != 0:
                zoom = cy / cy1
            elif cy == 0:
                zoom = cx / cx1
            if cx * cy == 0:
                cx = cx1 * zoom
                cy = cy1 * zoom
        p = ['positionH', 'positionV']
        postition = ''
        srcRect = ''
        bwMode = ''
        picPr = '<pic:cNvPicPr><a:picLocks noChangeAspect="1" noChangeArrowheads="1"/></pic:cNvPicPr>'
        noFill = '<a:noFill/>'
        wp14 = ''
        framePr = '<wp:cNvGraphicFramePr>'
        framePr += '<a:graphicFrameLocks noChangeAspect="1" xmlns:a="%s/main"/>' % schemas_open_draw_2006
        framePr += '</wp:cNvGraphicFramePr>'
        if wrap == 'tight':
            wrappp = '''
            <wp:wrapTight wrapText="bothSides">
                <wp:wrapPolygon edited="0">
                    <wp:start x="4719" y="0"/>
                    <wp:lineTo x="3267" y="2919"/>
                    <wp:lineTo x="2904" y="9341"/>
                    <wp:lineTo x="0" y="14011"/>
                    <wp:lineTo x="0" y="21016"/>
                    <wp:lineTo x="1089" y="21016"/>
                    <wp:lineTo x="1452" y="21016"/>
                    <wp:lineTo x="3630" y="18681"/>
                    <wp:lineTo x="21418" y="15762"/>
                    <wp:lineTo x="21418" y="2919"/>
                    <wp:lineTo x="7261" y="0"/>
                    <wp:lineTo x="4719" y="0"/>
                </wp:wrapPolygon>
            </wp:wrapTight>'''
            framePr = '<wp:cNvGraphicFramePr/>'
            picPr = '<pic:cNvPicPr/>'
        elif wrap == 'undertext':
            wrappp = '<wp:wrapNone/>'
            srcRect = '<a:srcRect/>'
            bwMode = ' bwMode="auto"'
            noFill = ''
            wp14 = '<wp14:sizeRelH relativeFrom="page"><wp14:pctWidth>0</wp14:pctWidth></wp14:sizeRelH>'
            wp14 += '<wp14:sizeRelV relativeFrom="page"><wp14:pctHeight>0</wp14:pctHeight></wp14:sizeRelV>'
        else:
            wrappp = '<wp:wrapNone/>'

        for i in range(0, len(p)):
            postition += '<wp:%s relativeFrom="%s">' % (p[i], relativeFrom[i])
            if align[i] != '':
                postition += '<wp:align>%s</wp:align></wp:%s>' % (align[i], p[i])
            else:
                postition += '<wp:posOffset>%d</wp:posOffset></wp:%s>' % (int(posOffset[i] * 359410), p[i])
        run = '<w:r><w:drawing><wp:%s distT="0" distB="0" ' % text_wrapping
        extent_r = 9525
        behindDoc = 0 if wrap == 'behinddoc' else 1
        if text_wrapping == 'anchor':
            run += 'distL="114300" distR="114300" simplePos="0" relativeHeight="251658240" behindDoc="%d" locked="0" layoutInCell="1" allowOverlap="1">' % behindDoc
            run += '<wp:simplePos x="0" y="0"/>'
            run += postition
        elif text_wrapping == 'inline':
            run += 'distL="0" distR="0">'
            wrappp = ''
            extent_r = 0
            noFill += '<a:ln w="9525"><a:noFill/><a:miter lim="800000"/><a:headEnd/><a:tailEnd/></a:ln>'
        run += '<wp:extent cx="%d" cy="%d"/>' % (int(cx * 359410), int(cy * 359410))
        run += '<wp:effectExtent l="0" t="0" r="%d" b="0"/>%s<wp:docPr id="1" name="图片 1"/>' % (extent_r, wrappp)
        run += framePr
        run += '<a:graphic xmlns:a="%s/main">' % schemas_open_draw_2006
        run += '<a:graphicData uri="%s/picture">' % schemas_open_draw_2006
        run += '<pic:pic xmlns:pic="%s/picture"><pic:nvPicPr><pic:cNvPr id="0" name=""/>' % schemas_open_draw_2006
        run += picPr

        run += '</pic:nvPicPr><pic:blipFill>'
        run += '<a:blip r:embed="rId%s"' % rId.capitalize()
        if text_wrapping != 'inline':
            run += ' cstate="print"><a:extLst><a:ext uri="{28A0092B-C50C-407E-A947-70E740481C1C}">'
            run += '<a14:useLocalDpi val="0" xmlns:a14="http://schemas.microsoft.com/office/drawing/2010/main"/>'
            run += '</a:ext></a:extLst></a:blip>'
            run += srcRect
            fill_type = '<a:stretch><a:fillRect/></a:stretch>'
        else:
            run += '/>'
            fill_type = '<a:srcRect/><a:stretch><a:fillRect/></a:stretch>'
        run += '%s</pic:blipFill>' % fill_type
        run += '<pic:spPr%s>' % bwMode
        run += '<a:xfrm><a:off x="0" y="0"/><a:ext cx="%d" cy="%d"/></a:xfrm>' % (int(cx * 359410), int(cy * 359410))
        run += '<a:prstGeom prst="rect"><a:avLst/></a:prstGeom>%s</pic:spPr>' % noFill
        run += '</pic:pic></a:graphicData></a:graphic>%s' % wp14
        run += '</wp:%s></w:drawing></w:r>' % text_wrapping
        return run

    def radius(self, cx, cy, **kwargs):
        # 1cm = 72 / 2.54 pt 1in = 2.54cm = 25.4 mm = 72pt = 6pc
        cm2pt = 72 / 2.54
        cm2xml = 359410
        shape = 'roundrect' if 'shape' not in kwargs else kwargs['shape']
        run = '<w:r><w:pict><v:%s ' % shape
        run += 'style="position:%s;' % ('relative' if 'position' not in kwargs else kwargs['position'])
        run += 'text-align:%s;' % ('left' if 'text-align' not in kwargs else kwargs['text-align'])
        run += 'width:%.2fpt;' % (cm2pt * cx)
        run += 'height:%.2fpt;' % (cm2pt * cy)
        if 'rotation' in kwargs:
            run += 'rotation:%s;' % kwargs['rotation']
        run += 'fill'
        fangxiang = ['top', 'right', 'bottom', 'left']
        for i in range(4):
            f = fangxiang[i]
            for w in ['margin-', '', 'mso-wrap-distance-']:
                who = w + f
                run += '%s:%fpt;' % (who, 0 if who not in kwargs else kwargs[who] * cm2pt)
        run += 'z-index:%s; ' % (-1 if 'z-index' not in kwargs else kwargs['z-index'])
        run += '''visibility:visible;
                mso-wrap-style:square;
                mso-width-percent:0;
                mso-height-percent:0;
                mso-position-horizontal-relative:text;
                mso-position-vertical-relative:text;
                mso-width-percent:0;
                mso-height-percent:0;
                mso-width-relative:margin;
                mso-height-relative:margin;
                v-text-anchor:middle" '''
        radius = 0.05 if 'radius' not in kwargs else kwargs['radius']
        if radius > 0:
            run += 'arcsize="%ff" ' % (radius * cm2xml)
        if 'coordsize' in kwargs:
            run += 'coordsize="%d,%d" ' % (int(cx * cm2xml), int(cy * cm2xml))
        if 'fill-color' in kwargs:
            run += 'fillcolor="%s" ' % kwargs['fill-color']
        run += 'strokecolor="%s" ' % ('#92d050' if 'stroke-color' not in kwargs else kwargs['stroke-color'])
        run += 'strokeweight="%fpt">' % (0.2 if 'strokeweight' not in kwargs else kwargs['strokeweight'])
        if 'opacity' in kwargs:
            run += '<v:fill opacity="%f"/>' % kwargs['opacity']
        if 'para' in kwargs:
            run += '<v:textbox><w:txbxContent>%s</w:txbxContent></v:textbox>' % kwargs['para']
        run += '</v:%s></w:pict></w:r>' % shape
        return run

    def instr_text(self, text='', space=False):
        space1 = ''
        if space:
            space1 = ' xml:space="preserve"'
        if text == '1-3':
            text = 'TOC \o "1-3" \h \u '
        r1 = '<w:r><w:instrText%s>%s</w:instrText></w:r>' % (space1, text)
        return r1

    def fldChar(self, fldCharType='separate'):
        r1 = '<w:r><w:fldChar w:fldCharType="%s"/></w:r>' % fldCharType
        return r1

    def tab(self):
        r1 = '<w:r><w:rPr><w:rFonts w:eastAsiaTheme="%s"/></w:rPr><w:tab/></w:r>' % self.familyTheme
        return r1

    def style(self, text, val='af8'):
        r = '<w:r><w:rPr><w:rStyle w:val="%s"/><w:rFonts w:eastAsiaTheme="%s"/></w:rPr><w:t>%s</w:t></w:r>' % (val, self.familyTheme, text)
        return r

    def cat(self, item):
        run = ''
        if item['bm'] == bm_index0:
            run = self.fldChar('begin')
            run += self.instr_text('1-3', space=True)
            run += self.fldChar()
        font_set = {} if 'font_set' not in item else item['font_set']
        run += '<w:hyperlink w:anchor="_Toc%d" w:history="1">' % item['bm']
        if 'title' in item:
            run += self.text(item['title'], space=True, **font_set)
        if 'run' in item:
            run += item['run']
        run += self.tab()
        run += self.fldChar('begin')
        run += self.instr_text(' PAGEREF _Toc%d \h ' % item['bm'], space=True)
        run += self.text('')
        run += self.fldChar()
        if 'page' in item:
            run += self.text(item['page'], **font_set)
        run += self.fldChar('end')
        run += '</w:hyperlink>'
        return run

    def checked(self, size=16, bdSize=None):
        run_checked = self.fldChar('begin')
        run_checked += self.instr_text(r' eq \o\ac(', True)
        run_checked += self.text('□', (size+4) if bdSize is None else bdSize)
        run_checked += self.text(',√)', size)
        run_checked += self.fldChar('end')
        return run_checked


my_file = File()

r = Run(img_info_path)
hyperlink = HyperLink()
r.family_en = 'Times New Roman'
p = Paragraph()
set_page = Set_page().set_page
table = Table()
tr = Tr()
tc = Tc()

# 初号=42磅
# 小初=36磅
# 一号=26磅
# 小一=24磅
# 二号=22磅
# 小二=18磅
# 三号=16磅
# 小三=15磅
# 四号=14磅
# 小四=12磅
# 五号=10.5磅
# 小五=9磅
# 六号=7.5磅
# 小六=6.5磅
# 七号=5.5磅
# 八号=5磅


# ##################下载报告所需方法######################

def generate_word():
    file_name = 'my_word.doc'
    print u'%s begin.' % file_name
    imgs = get_imgs(os.path.dirname(__file__))
    my_file.write(img_info_path, imgs)
    body = p.h4('hello, my word!', size=28, spacing=[3, 3])
    body += p.write(r.radius(1, 3, para=p.write(r.text('rotation')), rotation='-90', shape='shape', path='df', coordsize=(0.5, 0.5)))
    tcs = tc.write(tc.set(2000), p.write(r.radius(3, 1, para=p.write(r.text('testdd')))))

    trs = tr.write(tcs, tr.set(trHeight=680))
    body += table.write(trs, [2000])
    # body += p.write(r.picture(cx=10, rId='ex'))
    pkg = write_pkg_parts(imgs, body, title=[])
    my_file.download(pkg, file_name)
    print u'%s over.' % file_name



if __name__ == '__main__':
    generate_word()



# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2019/5/23 0023
__author__ = 'huohuo'
from matplotlib import pyplot as plt
from matplotlib_venn import venn2
from jy_word.File import File
my_file = File()


def set_info(file_name):
    set11 = my_file.read(file_name).strip('\n').split('\n')
    return set(set11), file_name


if __name__ == "__main__":
    set1, l1 = set_info('nodbsnp.list')
    set2, l2 = set_info('hg19_id.list')
    venn2(subsets=[set1, set2], set_labels=(l1, l2), set_colors=['r', 'g'])
    plt.savefig('test.png')
    pass
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2018/11/7 0007
__author__ = 'huohuo'
import os
import requests
import logging
import time
import socket
import zipfile
import shutil
import re
import sys
reload(sys)
sys.setdefaultencoding('utf-8')
from JYAliYun.AliYunMNS.AliMNSServer import MNSServerManager

# "错误消息通知群"
# "霍佩佩专用机器人"
# "e61184c4450f33a3313dc5651f7e63ed64c1e2e1f4dd37b585ffda93e9e801ee",
# 前端测试 通知
# https://oapi.dingtalk.com/robot/send?access_token=f0e012537fb60ac5e37be4239e9380e574eb65574f36446f7160750db9f413fe
#! /usr/bin/env python
# coding: utf-8


def test_chinese(contents):
    zhPattern = re.compile(u'[\u4e00-\u9fa5]+')
    # 一个小应用，判断一段文本中是否包含简体中：
    match = zhPattern.search(contents)
    if match:
        a = zhPattern.findall(contents)
        ch_num = 0
        for i in a:
            ch_num += len(i)
        return ch_num
    return 0


def sex2str(sex):
    if sex == 0:
        return '未知'
    elif sex == 1:
        return '男'
    else:
        return '女'


def float2percent(p):
    f = str(p).strip()
    if f in [u'无', 'None', '']:
        return 'N/A'
    elif f == "<1%":
        return f.replace("<", "&lt;")
    elif f == ">99%":
        return f
    elif '%' in f:
        return f
    else:
        f = '%.2f%%' % float(f)
    return f


def int2ch(i):
    chs = ['零', '一', '二', '三', '四', '五', '六', '七', '八', '九', '十']
    return chs[i]


def zip_dir(lodurl, dirname, zipfilename, fileList=None):

    file_list = fileList or []
    #Check input ...
    fulldirname = dirname
    fullzipfilename = os.path.join(lodurl, zipfilename)
    print "Start to zip %s to %s ..." % (fulldirname, fullzipfilename)
    if not os.path.exists(fulldirname):
        print "Dir/File %s is not exist, Press any key to quit..." % fulldirname
        inputStr = raw_input()
        return
    if os.path.isdir(fullzipfilename):
        tmpbasename = os.path.basename(dirname)
        fullzipfilename = os.path.normpath(os.path.join(fullzipfilename, tmpbasename))
    if os.path.exists(fullzipfilename):
        print "%s has already exist, are you sure to modify it ? [Y/N]" % fullzipfilename
        while 1:
            inputStr = raw_input()
            if inputStr == "N" or inputStr == "n" :
                return
            else:
                if inputStr == "Y" or inputStr == "y" :
                    print "Continue to zip files..."
                    break

    #Get file(s) to zip ...
    if os.path.isfile(dirname):
        file_list.append(dirname)
        dirname = os.path.dirname(dirname)
    elif os.path.isdir(dirname):
        #get all file in directory
        for filename in os.listdir(dirname):
            file_list.append(os.path.join(dirname, filename))

    #Start to zip file ...
    destZip = zipfile.ZipFile(fullzipfilename, "w")
    i = 0
    for eachfile in file_list:
        destfile = eachfile[len(dirname):]
        print "Zip file %s..." % destfile
        destZip.write(eachfile, destfile)
        i += 1
    destZip.close()
    if i == len(file_list):
        return 5
    return 3


def roman_to_int(s):
    #     1~10: I II III IV V VI VII VIII IX X
    #     11~20: XI XII XIII XIV XV XVI XVII XVIII XIX XX
    """
    :type s: str
    :rtype: int
    """

    if s == 'Ⅲ':
        return 3
    elif s == 'Ⅴ':
        return 5
    elif s == 'Ⅷ':
        return 8
    else:
        try:
            romanInt = {'I': 1, 'V': 5, 'X': 10, 'L': 50, 'C': 100,'D': 500,'M': 1000}
            num = romanInt[s[0]]
            for i in range(1,len(s)):
                if romanInt[s[i]] > romanInt[s[i - 1]]:
                    num += romanInt[s[i]] - 2 * romanInt[s[i - 1]]
                else:
                    num += romanInt[s[i]]
            return num
        except:
            try:
                return int(s)
            except:
                print s


def send_msg_by_mns(message, **kwargs):
    """
    消息类型为文本时，data 格式如下：
    data = {
        "msgtype": "text",
        "text": {
            "content": "错误日志通知测试2017-08-21 10:14"
        },
        "at": {
            "atMobiles": [
                "18612660303",
                "15538819853"
            ],
            "isAtAll": True # True 表示@ALL, False 表示只 @ atMobiles 中的
        }
    }
    :param message:
    :param type: 消息类型，默认 text
    :param kwargs: 备用参数: mobile_phone 手机号，表示通知人，
                            access_token 通知机器人值，表示用哪个机器人
    :return:
    """
    use_mns = False
    MNS_CONF_PATH = os.environ.get('MNS_CONF_PATH')
    if MNS_CONF_PATH is not None:
        if os.path.exists(MNS_CONF_PATH):
            use_mns = True
        else:
            message = '\n【MNS_CONF_FILE】： %s not exists.\n\n%s\n' % (MNS_CONF_PATH, message)

    if use_mns:
        message += '\n【时间】：%s' % format_time()
        mns_server = MNSServerManager(conf_path=MNS_CONF_PATH)
        mns_topic = mns_server.get_topic("JYWaring")
        mns_topic.publish_message(message, "前端错误", is_thread=False)
    else:
        send_msg_by_dd(message)


def send_msg_by_dd(message, **kwargs):
    """
    消息类型为文本时，data 格式如下：
    data = {
        "msgtype": "text",
        "text": {
            "content": "错误日志通知测试2017-08-21 10:14"
        },
        "at": {
            "atMobiles": [
                "18612660303",
                "15538819853"
            ],
            "isAtAll": True # True 表示@ALL, False 表示只 @ atMobiles 中的
        }
    }
    :param message:
    :param type: 消息类型，默认 text
    :param kwargs: 备用参数: mobile_phone 手机号，表示通知人，
                            access_token 通知机器人值，表示用哪个机器人
    :return:
    """
    access_token = '136f44ec383377d7980bb43e9b8acb1eac0c1f6a6b31d6ba3ba10d43923751f8'
    env = get_value(kwargs, 'env', '环境')
    mobile_phone = get_value(kwargs, 'mobile_phone', '15538819853')
    txt_data = {
        "msgtype": "text",
        "text": {"content": '【Env】: %s\n%s\n【时间】：%s' % (env, message.rstrip('\n'), format_time())},
        "at": {
            # "atMobiles": [mobile_phone],
            "isAtAll": False}
    }
    url = "https://oapi.dingtalk.com/robot/send?access_token=%s" % access_token
    header = {"Content-Type": "application/json"}
    try:
        requests.post(url, json=txt_data, headers=header, timeout=2)
    except Exception, e:
        logging.error(e.args)


def format_time(t=None, frm="%Y-%m-%d %H:%M:%S"):
    if t is None:
        t = time.localtime()
    if type(t) == int:
        t = time.localtime(t)
    my_time = time.strftime(frm, t)
    return my_time


def get_host(web_port, print_msg=''):
    host_name = socket.gethostname()
    host = socket.gethostbyname(host_name)
    url = 'http://%s:%s' % (host, web_port)
    print 'ip: "%s", name: %s, port: %d' % (host, host_name, web_port)
    print url
    if len(print_msg) > 0:
        print print_msg
    return {'ip': host, 'name': host_name, 'port': web_port, 'url': url}


def killport(port):
    command='''''kill -9 $(netstat -nlp | grep :'''+str(port)+''''' | awk '{print $7}' | awk -F"/" '{ print $1 }')'''
    os.system(command)


def get_value(disease_item, key, null=None):
    if isinstance(disease_item, dict):
        if key in disease_item:
            value = disease_item[key]
            if value is None:
                return null
            if isinstance(value, unicode) or isinstance(value, str):
                if value.strip() == '':
                    return null
                return value.strip()
            return value
    return null


def get_first_name(data):
    double_surnames = u'''欧阳、太史、端木、上官、司马、东方、独孤、南宫、万俟、闻人、夏侯、诸葛、尉迟、公羊、赫连、澹台、皇甫、宗政、濮阳、公冶、太叔、申屠、公孙、慕容、仲孙、钟离、长孙、宇文、司徒、鲜于、司空、闾丘、子车、亓官、司寇、巫马、公西、颛孙、壤驷、公良、漆雕、乐正、宰父、谷梁、拓跋、夹谷、轩辕、令狐、段干、百里、呼延、东郭、南门、羊舌、微生、公户、公玉、公仪、梁丘、公仲、公上、公门、公山、公坚、左丘、公伯、西门、公祖、第五、公乘、贯丘、公皙、南荣、东里、东宫、仲长、子书、子桑、即墨、达奚、褚师、吴铭'''
    name = data.get('name')
    if name is None:
        name = data.get('patient_name')
    if name is None:
        name = 'None'
    else:
        sex = data.get('sex')
        if sex is None:
            sex = data.get('gender')
        if name[:2] in double_surnames:
            surname = name[:2]
        else:
            surname = name[:1]
        if sex in [1, u'男']:
            name = surname + u"先生"
        elif sex in [2, u'女']:
            name = surname + u"女士"
    return name


def tcm_api():
    # 配置文件
    conf = read_conf()
    ports = conf.get('ports')
    endpoint = conf.get('endpoint')
    env = conf.get('env')
    # 请求相关
    method = request.method
    data = request.args if method == 'GET' else request.json
    url = request.headers.get('API-URL')
    api_service = request.headers.get('API-SERVICE')
    success_status = request.headers.get('SUCCESS-STATUS')
    api_method = request.headers.get('API-METHOD')
    if api_method is not None:
        method = api_method
    auth = request.headers.get('Authorization')
    # start
    error_message = ''
    response_data = None
    status = None
    if isinstance(conf, str):
        error_message = conf
    if ports is None:
        error_message = 'No ports found in config.conf'
    elif api_service not in ports:
        error_message = u'暂无此服务：%s. 目前服务有：%s\n' % (api_service, ports.keys())
    else:
        api_url = endpoint + ':' + ports[api_service] + url
        request_params = {'json': data} if method != 'GET' else {'params': data}
        headers = {'Content-Type': 'application/json'}
        if auth:
            headers['Authorization'] = auth
        request_params['headers'] = headers
        try:
            response = requests.request(method, api_url, **request_params)
        except Exception, e:
            error_message = '%s\n' % str(e)
            response = None
        if response is not None:
            if response.status_code != 200:
                error_message = "%s %s %d %s\n" % (api_url, "POST", response.status_code, response.text)
            else:
                response_data = response.json()
                status = response_data.get('status')
        error_message += u'【请求服务】：%s\n' % api_service
        error_message += u'【api】：%s\n' % api_url
    error_message += u'【访问ip】：%s\n' % request.remote_addr
    error_message += u'【访问地址】：%s\n' % request.url
    error_message += u'【请求方式】：%s\n' % method
    error_message += u'【请求数据】：%s\n' % json.dumps(data)
    if status is not None:
        error_message += u'【状态码】:%d\n' % status
    error_message += u'【返回数据】：%s\n' % json.dumps(response_data)
    try:
        sss = base64.b64decode(auth).decode()
        error_message += u'【用户名】：%s\n' % sss.split(':')[0]
    except:
        error_message += ''
    # if self.is_print:
    #     print error_message
    if 'success' not in error_message.lower():
        try:
            send_msg_by_dd(error_message, env=env)
        except:
            print(error_message)
    return jsonify(response_data)


def del_file(path):
    if os.path.exists(path) is False:
        return 'path not exists, %s' % path
    if os.path.isfile(path):
        os.remove(path)
        return True
    try:
        shutil.rmtree(path)
    except:
        os.rmdir(path)



if __name__ == "__main__":
    send_msg_by_dd('sss')
    pass
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2019/5/28 0028
__author__ = 'huohuo'
from jy_word.File import File
from jy_word.web_tool import format_time
import uuid
my_file = File()


def get_uuid():
    uid = uuid.uuid1().hex
    return uid


templates = my_file.read('tcm_template.json')
# print d
templates1 = []
for template in templates:
    blocks = template.get('items') or []
    template['template'] = get_uuid()
    blocks2 = []
    for block in blocks:
        bb = block.get('items') or []
        block['entry_name'] = block['title']
        del block['title']
        block['block_id'] = get_uuid()
        bb1 = []
        for item in bb:
            print item.keys(), item.get('text')
            input_items = item.get('input_items') or []
            for ii in input_items:
                # print ii.keys()
                uid = get_uuid()
                ii['item_id'] = uid
                ii['item_name'] = ii.get('label')
                if 'field' in ii:
                    ii['field'] = ii['item_id']
                # elif ii.get('is_group'):
                #     group = ii.get('is_group')
                #     print ii
                elif 'items' in ii:
                    group = ii.get('is_group')
                    items = ii.get('items')
                    for iiii, iii in enumerate(items):
                        if 'field' in ii:
                            iii['field'] = get_uuid()
                        elif group:
                            iii['field'] = '%s%s' % (uid, iiii)
                        else:
                            print iii
                elif ii.get('is_list'):
                    data = ii.get('data')
                    ids = []
                    for datai in range(len(data)):
                        ids.append('%s%s' % (uid, datai))
                    ii['uuids'] = ids
                else:
                    print ii.keys()
                # for k in ii:
                #     if (type(ii[k])) not in ['unicode', 'str']:
                #         ii[k] = json.dumps(ii[k])
            bb11 = {'items': input_items, 'entry_name': item.get('text'), 'block_id': get_uuid()}
            for k in item.keys():
                if k not in bb11:
                    bb11[k] = item[k]
            bb1.append(bb11)
        blocks2.append(bb1)
    templates1.append(blocks2)


# my_file.write('tcm_template1.json', templates)
import requests
import easygui as eg
from requests.auth import HTTPBasicAuth

auth = HTTPBasicAuth('hpp_test', 'hpp.123456')
headers = {'Content-Type': 'application/json'}
print auth.username
rq_template = get_uuid()
template_name = '普适版%s' % format_time(frm='%m%d%H%M')
template_name = eg.enterbox('模板标题', default=template_name)
rq_data = {
    'template_name': template_name,
    # 'template_name': '普适版',
    'template': rq_template,
    'template_info': templates1[0]
}
rq_data = my_file.read('tcm_template_online.json')[0]
rq_data['template'] = rq_template
rq_data['template_name'] = template_name
my_file.write('%s.json' % rq_template, rq_data)
response = requests.request('post', 'http://192.168.105.4:8000/api/v2/detection/template/', auth=auth, headers=headers, json=rq_data)
# rq = requests.request('post', 'http://10.120.1.105:8000/api/v2/project/', auth=auth, headers=headers)
# rq = requests.request('post', 'http://10.6.50.248:8000/api/v2/project/', auth=auth, headers=headers)
print response.status_code
if response.status_code == 200:
    response_data = response.json()
    api_data = response_data.get('data')
    if api_data:
        print 'post success', rq_template, api_data.get('template_name')
    else:
        print response_data
my_file.write('tcm_template2.json', templates1)


if __name__ == "__main__":
    pass
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2018/10/17 0017
__author__ = 'huohuo'
import re
import os
import urllib
#根据给定的网址来获取网页详细信息，得到的html就是网页的源代码
def getHtml(url):
    page = urllib.urlopen(url)
    html = page.read()
    return html.decode('UTF-8')

def getImg(html):
    reg = r'src="(.+?\.jpg)" pic_ext'
    imgre = re.compile(reg)
    imglist = imgre.findall(html)#表示在整个网页中过滤出所有图片的地址，放在imglist中
    x = 0
    path = u'H:\晶云公司\\1.需求文档\下载报告\晶苗\\3.新版\图片2'
   # 将图片保存到D:\\test文件夹中，如果没有test文件夹则创建
    if not os.path.isdir(path):
        os.makedirs(path)
    paths = path+'\\'      #保存在test路径下

    for imgurl in imglist:
        urllib.urlretrieve(imgurl,'{}{}.jpg'.format(paths,x))  #打开imglist中保存的图片网址，并下载图片保存在本地，format格式化字符串
        x = x + 1
    return imglist
html = getHtml("http://tieba.baidu.com/p/2460150866")#获取该网址网页详细信息，得到的html就是网页的源代码
print (getImg(html)) #从网页源代码中分析并下载保存图片
if __name__ == "__main__":
    pass
    

